# Seaborn Table
Seaborn Table acts as a dictionary and list and handles reading and writing data 
to various formats seamlessly.

It can do this by consuming:
    list of list
    list of dictionary
    dictionary of dictionary
    dictionary of lists

It can consume these from raw python data structures, csv, text, markdown, 
grid, psql, or file.
It can output to csv, text, markdown, grid, psql, rst or html tables.

This is primarily as a library but can be used as a script with:
> seaborn_table source_file destination_file
